#
# spec file for package perl-common-sense
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-common-sense
Version:        3.5
Release:        1.1
%define cpan_name common-sense
Summary:        Save a tree AND a kitten (sane defaults for Perl programs)
License:        GPL-1.0+ or Artistic-1.0
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/common-sense/
Source:         http://www.cpan.org/authors/id/M/ML/MLEHMANN/%{cpan_name}-%{version}.tar.gz
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
#BuildRequires: perl(common::sense)
%{perl_requires}

%description
This module implements some sane defaults for Perl programs, as defined
by two typical (or not so typical - use your common sense) specimens of
Perl coders. In fact, after working out details on which warnings and
strict modes to enable and make fatal, we found that we (and our code
written so far, and others) fully agree on every option, even though we
never used warnings before, so it seems this module indeed reflects a
"common" sense among some long-time Perl coders.

The basic philosophy behind the choices made in common::sense can be
summarised as: "enforcing strict policies to catch as many bugs as
possible, while at the same time, not limiting the expressive power
available to the programmer".


%prep
%setup -q -n %{cpan_name}-%{version}
find . -type f -print0 | xargs -0 chmod 644

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes LICENSE README

%changelog
* Wed May 23 2012 coolo@suse.com
- updated to 3.5
  - localise $^W, as this causes warnings with 5.16 when some lost
    soul uses -w. common::sense doesn't support $^W, but tries to
    shield module authors and programs from its ill effects. If you
    enable $^W, then you normally get to keep the pieces because you
    change semantics of other people's code.
* Fri Mar  4 2011 chris@computersalat.de
- update to 3.4
  - remove "regexp" category. this is rather painful as it's a large
    class, but unfortunately, somebody thought emitting a warning when
    you match more than 32kb of text is in some way useful, which
    spoils the whole category.
  - use META.json instead of META.yml - apparently YAML parsers don't
    actually exist.
- recreated by cpanspec 1.78.03
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Tue Jul  6 2010 chris@computersalat.de
- update tp 3.3
  - removed "exiting" category - this is too useful to create new
    control statements, and fails utterly with eval, as eval will
    catch the (fatal) warning itself. Kind of hurts, but this is
    just another warning category which is too broad and has to be
    disabled fully because of a minority of issues.
- noarch package
  o remove .packlist/perllocal.pod
* Fri Apr 16 2010 chris@computersalat.de
- update to 3.2
  - removed "substr" warning - while it overall is a good category,
    "substr '', 2" is entirely sensible.
- 3.1  Sat Apr  3 04:56:36 CEST 2010
  - removed "parenthesis" warning:
    sysread $fh, my $buf, -s $fh; # ok
    sysread $fh, my $buf, $size;  # warning
    Made no sense to me, especially as $size is in scope.
  - no longer hardcode warning/struct bits, calculate them at
    installation time, for when I will no longer be alive etc.
  - tweaked documentation.
- fixed perl-macros deps
* Mon Jan 18 2010 jw@novell.com
- update to 3.0, as suggested by JSON::XS
* Fri Sep  4 2009 chris@computersalat.de
- initial pkg 2.0
